import { EngineContext } from '@/composables/useEngine'
import type { GameInfo, PlayerEdit } from '@/composables/engine.d'
import { useUserinfoStore } from "@/stores/UserinfoStore"

export async function collectQuotes(this: EngineContext): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/collectQuotes', {
    g: userInfoStore.gameId,
  })
}

export async function startGame(this: EngineContext): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/startGame', {
    g: userInfoStore.gameId,
  })
}

export async function continueGame(this: EngineContext): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/continueGame', {
    g: userInfoStore.gameId,
  })
}

export async function resetGame(this: EngineContext): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/resetGame', {
    g: userInfoStore.gameId,
  })
}

export async function finishGame(this: EngineContext): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/finishGame', {
    g: userInfoStore.gameId,
  })
}

export async function fetchGameInfo(this: EngineContext): Promise<GameInfo> {
  const userInfoStore = useUserinfoStore()
  return await this.callApi('/api/gameinfo', {
    g: userInfoStore.gameId,
  }) as GameInfo
}

export async function setGameLang(this: EngineContext, lang: string): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/setGameLang', {
    g: userInfoStore.gameId,
    lang,
  })
}

export async function setGameName(this: EngineContext, name: string): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/setGameName', {
    g: userInfoStore.gameId,
    name,
  })
}

export async function savePlayer(this: EngineContext, player: PlayerEdit): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/savePlayer', {
    g: userInfoStore.gameId,
    id: player.id,
    name: player.name,
    score: player.score.toString(),
    authcode: player.authcode,
  })
}

